Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2117)

Unified Diff: chrome/browser/download/download_manager.h

Issue 6060008: Adding active_downloads_ map. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Expanded comment. Created 9 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/download/download_manager.h
diff --git a/chrome/browser/download/download_manager.h b/chrome/browser/download/download_manager.h
index 4f5ebcfb1cbcb6722f35c05b30642787927fb08e..17f8e1200295d609a6a8a77d8845f98c2add01a5 100644
--- a/chrome/browser/download/download_manager.h
+++ b/chrome/browser/download/download_manager.h
@@ -119,6 +119,7 @@ class DownloadManager
void StartDownload(DownloadCreateInfo* info);
void UpdateDownload(int32 download_id, int64 size);
void OnAllDataSaved(int32 download_id, int64 size);
+ void OnDownloadFileCompleted(int32 download_id);
// Called from a view when a user clicks a UI button or link.
void DownloadCancelled(int32 download_id);
@@ -310,6 +311,10 @@ class DownloadManager
// is the handle returned by the history system, which is unique
// across sessions.
//
+ // |active_downloads_| is a map of all downloads that are currently being
+ // processed. The key is the ID assigned by the ResourceDispatcherHost,
Paweł Hajdan Jr. 2011/01/05 08:11:16 nit: "being processed" is extremely vague. Could y
ahendrickson 2011/01/06 16:48:52 Is "active" any better? It will eventually replac
Paweł Hajdan Jr. 2011/01/06 20:39:34 Okay, ignore it for now. We can do it the right wa
+ // which is unique for the current session.
+ //
// |in_progress_| is a map of all downloads that are in progress and that have
// not yet received a valid history handle. The key is the ID assigned by the
// ResourceDispatcherHost, which is unique for the current session.
@@ -319,11 +324,12 @@ class DownloadManager
// until we are destroyed. It is only used for debugging.
//
// When a download is created through a user action, the corresponding
// DownloadItem* is placed in |in_progress_| and remains there until it has
// received a valid handle from the history system. Once it has a valid
// handle, the DownloadItem* is placed in the |history_downloads_|
// map. When the download is complete, it is removed from
// |in_progress_|. Downloads from past sessions read from a
// persisted state from the history system are placed directly into
// |history_downloads_| since they have valid handles in the history system.
typedef std::set<DownloadItem*> DownloadSet;
@@ -332,6 +338,7 @@ class DownloadManager
DownloadSet downloads_;
DownloadMap history_downloads_;
DownloadMap in_progress_;
+ DownloadMap active_downloads_;
#if !defined(NDEBUG)
DownloadSet save_page_as_downloads_;
#endif
@@ -319,11 +324,12 @@ class DownloadManager
//
// When a download is created through a user action, the corresponding
- // DownloadItem* is placed in |in_progress_| and remains there until it has
- // received a valid handle from the history system. Once it has a valid
- // handle, the DownloadItem* is placed in the |history_downloads_|
- // map. When the download is complete, it is removed from
- // |in_progress_|. Downloads from past sessions read from a
+ // DownloadItem* is placed in |active_downloads_| and remains there until the
+ // download has finished. It is also placed in |in_progress_| and remains
+ // there until it has received a valid handle from the history system. Once
+ // it has a valid handle, the DownloadItem* is placed in the
+ // |history_downloads_| map. When the download is complete, it is removed
+ // from |in_progress_|. Downloads from past sessions read from a
// persisted state from the history system are placed directly into
// |history_downloads_| since they have valid handles in the history system.

Powered by Google App Engine
This is Rietveld 408576698